@@ -11,6 +11,10 @@ def options_updated(value, item):
     item.set({"allowed": value})
 
 
+def value_updated(value, item):
+    item.set({"value": value})
+
+
 def set_daemon(value, property):
     property(value["value"])
 
@@ -24,6 +28,8 @@ def Enum(key, property, qclient):
     # make item
     item = qtypes.Enum(disabled=disabled, label=key)
     # signals and slots
+    property.updated.connect(partial(options_updated, item=item))
+    property()
     property.options.finished.connect(partial(options_updated, item=item))
     property.options()
     item.edited.connect(partial(set_daemon, property=property))
